@@ -1,11 +1,11 @@
-const fixtureId = 'fixture'
+const FIXTURE_ID = 'fixture'
 
 export const getFixture = () => {
-  let fixtureElement = document.getElementById(fixtureId)
+  let fixtureElement = document.getElementById(FIXTURE_ID)
 
   if (!fixtureElement) {
     fixtureElement = document.createElement('div')
-    fixtureElement.setAttribute('id', fixtureId)
+    fixtureElement.setAttribute('id', FIXTURE_ID)
     fixtureElement.style.position = 'absolute'
     fixtureElement.style.top = '-10000px'
     fixtureElement.style.left = '-10000px'
